slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPSTOARGetCheckEigenvalueType

Gets the flag for the eigenvalue type check in spectrum slicing.

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPSTOARGetCheckEigenvalueType(PEP pep,PetscBool *checket)

Not Collective

### Input Parameter

| pep | - the eigenproblem solver context

### Output Parameter

| checket | - whether eigenvalue type must be checked during spectrum slcing

### See Also

PEPSTOARSetCheckEigenvalueType()

### Level

advanced

### Location

src/pep/impls/krylov/stoar/stoar.c
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages